import React from 'react';
import style from './index.less';
import {
  DatePicker,
  Select,
  Button,
  Checkbox,
  Row,
  Col,
  Dropdown,
  Menu,
  TreeSelect,
} from 'antd';
const { Option } = Select;
import moment from 'moment';
import 'moment/locale/zh-cn';
import locale from 'antd/lib/date-picker/locale/zh_CN';
moment.locale('zh-cn');

export class TopBar extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      fclasslist: [],
      companylist: [], //下拉框跟节点
      treeExpandedKeys: [],
      companyData: [],
      departmentData: [],
      companyTreeData: [],
      deptartmentTreeData: [],
      requestData: {
        date: moment(new Date()).format('YYYY-MM-DD'),
        fclass: '0',
        root: '0',
        level: '3',
        fisvitual: '0',
        company: undefined,
        department: undefined,
      },
    };
  }

  handleFormChange(payload) {
    let requestData = { ...this.state.requestData, ...payload };
    this.setState({ requestData });
  }
  //日期可选择未来
  // disabledDate (current)  {
  //   // return current && current >moment().subtract(1, "days");
  // return current && current > moment().endOf("day");
  // }

  handleExportMenuClick(e) {
    this.props.onExport(e.key == '1' ? 'png' : 'pdf');
  }

  handleExportButtonClick() {
    this.props.onExport('png');
  }

  /**
   * 分部
   * @param {*} parentId
   */
  getCompanyTreeNode = (parentId) => {
    let api =
      '/api/bs/hrmorganization/jclorgchart/getCompanyTree?company=' + parentId;
    fetch(api)
      .then((res) => res.json())
      .then((data) => {
        if (data.code == 200) {
          let arr = [...this.state.companyTreeData, ...data.data];
          this.setState({
            companyTreeData: arr,
          });
        }
      });
  };

  /**
   * 部门
   * @param {} parentId
   * @returns
   */
  getDepartmentTreeNode = (parentId) => {
    let api =
      '/api/bs/hrmorganization/jclorgchart/getDepartmentTree?department=' +
      parentId;
    fetch(api)
      .then((res) => res.json())
      .then((data) => {
        if (data.code == 200) {
          let arr = [...this.state.deptartmentTreeData, ...data.data];
          this.setState({
            deptartmentTreeData: arr,
          });
        }
      });
  };

  onCompanyLoadData = (treeNode) =>
    new Promise((resolve) => {
      const { id } = treeNode.props;
      setTimeout(() => {
        this.getCompanyTreeNode(id);
        resolve();
      }, 300);
    });

  onDepartmentLoadData = (treeNode) =>
    new Promise((resolve) => {
      const { id } = treeNode.props;
      setTimeout(() => {
        this.getDepartmentTreeNode(id);
        resolve();
      }, 300);
    });

  onCompanyChange = (value, label, extra) => {
    let company = value.length > 0 ? this.paramsUtil(value) : undefined;
    let requestData = {
      ...this.state.requestData,
      company: company,
      department: undefined,
    };
    this.setState({
      companyData: value,
      requestData,
      departmentData: [],
      deptartmentTreeData: [],
      treeExpandedKeys: [],
    });
    this.getDepartmentTreeList(company);
  };

  onDepartmentChange = (value) => {
    let department = value.length > 0 ? this.paramsUtil(value) : undefined;
    let requestData = { ...this.state.requestData, department: department };
    this.setState({ departmentData: value, requestData });
  };

  getCompanyTreeList = () => {
    let api = '/api/bs/hrmorganization/jclorgchart/getCompanyTree';
    fetch(api)
      .then((res) => res.json())
      .then((data) => {
        if (data.code == 200) {
          this.setState({
            companyTreeData: data.data,
          });
        }
      });
  };

  getDepartmentTreeList = (company) => {
    let api = `/api/bs/hrmorganization/jclorgchart/getDepartmentTree?company=${company}`;
    fetch(api)
      .then((res) => res.json())
      .then((data) => {
        if (data.code == 200) {
          this.setState({
            deptartmentTreeData: data.data,
          });
        }
      });
  };

  paramsUtil = (param) => {
    let arr = param.map(function (obj, index) {
      return obj.value;
    });
    return arr.join(',');
  };

  onTreeExpand = (expandedKeys) => {
    this.setState({
      treeExpandedKeys: expandedKeys,
    });
  };

  componentDidMount() {
    fetch(this.props.url)
      .then((res) => res.json())
      .then((data) => {
        this.setState({
          fclasslist: data.fclasslist,
          companylist: data.companylist,
        });
      });
    this.getCompanyTreeList();
  }

  menu = (
    <Menu
      onClick={this.handleExportMenuClick.bind(this)}
      items={[
        {
          label: '导出图片',
          key: '1',
        },
        {
          label: '导出PDF',
          key: '2',
        },
      ]}
    />
  );

  render() {
    const { companyTreeData, deptartmentTreeData, treeExpandedKeys } =
      this.state;

    return (
      <div className={style.topbarWrapper}>
        <Row>
          <Col span={6}>
            数据日期：
            <DatePicker
              placeholder="请选择日期"
              style={{ width: 130 }}
              locale={locale}
              allowClear={false}
              disabledDate={this.disabledDate}
              defaultValue={moment(new Date())}
              value={
                this.state.requestData.date && this.state.requestData.date != ''
                  ? moment(this.state.requestData.date)
                  : ''
              }
              onChange={(value) =>
                this.handleFormChange({
                  date: value && value != '' ? value.format('YYYY-MM-DD') : '',
                })
              }
            />
          </Col>

          <Col span={6}>
            维度：
            <Select
              defaultValue="0"
              style={{ width: 120 }}
              value={this.state.requestData.fclass}
              onChange={(value) => this.handleFormChange({ fclass: value })}
            >
              {this.state.fclasslist.map((item) => (
                <Option value={item.id}>{item.companyname}</Option>
              ))}
            </Select>
          </Col>

          <Col span={6}>
            分部：
            <TreeSelect
              showSearch
              allowClear
              treeDataSimpleMode
              treeCheckable
              treeCheckStrictly
              showCheckedStrategy={TreeSelect.SHOW_ALL}
              style={{ width: '80%' }}
              value={this.state.companyData}
              dropdownStyle={{ maxHeight: 400, overflow: 'auto' }}
              placeholder="请选择分部节点"
              onChange={this.onCompanyChange}
              loadData={this.onCompanyLoadData}
              treeData={companyTreeData}
            />
          </Col>

          <Col span={6}>
            部门：
            <TreeSelect
              showSearch
              allowClear
              treeDataSimpleMode
              treeCheckable
              showCheckedStrategy={TreeSelect.SHOW_ALL}
              treeExpandedKeys={treeExpandedKeys}
              treeCheckStrictly
              style={{ width: '80%' }}
              value={this.state.departmentData}
              dropdownStyle={{ maxHeight: 400, overflow: 'auto' }}
              placeholder="请选择部门节点"
              onChange={this.onDepartmentChange}
              loadData={this.onDepartmentLoadData}
              treeData={deptartmentTreeData}
              onTreeExpand={this.onTreeExpand}
            />
          </Col>
        </Row>
        <Row style={{ marginTop: '15px' }}>
          <Col span={6}>
            显示层级：
            <Select
              defaultValue="3"
              style={{ width: 120 }}
              value={this.state.requestData.level}
              onChange={(value) => this.handleFormChange({ level: value })}
            >
              <Option value="1">一级</Option>
              <Option value="2">二级</Option>
              <Option value="3">三级</Option>
            </Select>
          </Col>

          <Col span={6}>
            <Checkbox
              style={{ marginTop: '5px' }}
              onChange={(e) =>
                this.handleFormChange({
                  fisvitual: e.target.checked ? '1' : '0',
                })
              }
            >
              显示虚拟组织
            </Checkbox>
          </Col>
          <Col span={6}>
            <Button
              type="primary"
              style={{ marginRight: '10px' }}
              onClick={() => {
                this.props.onSearch(this.state.requestData);
              }}
            >
              查询
            </Button>
            <Dropdown overlay={this.menu}>
              <Button>导出</Button>
            </Dropdown>
          </Col>
        </Row>
      </div>
    );
  }
}
